import { Utilities } from '@/util/Utilities';
import {
    Form,
    Modal, ModalService, Password,
    TextInput,
} from '@zeedhi/common';
import {
    Config, Http, IEventParam, Metadata, Singleton,
} from '@zeedhi/core';

@Singleton
export class LoginController {
    get logo() {
        return Config.env.product.logoUrl;
    }

    get backgroundImgUrl() {
        const url = Config.env.loginBackgroundImgUrl;
        return `url(${url})`;
    }

    get endPoint() {
        return Config.env.loginEndPoint;
    }

    private signUpModal!: Modal;

    public async openSignUpModal() {
        this.signUpModal = await ModalService.createFromJson('/sign_up_modal', true);
        this.signUpModal.show();
    }

    public closeSignUpModal() {
        this.signUpModal.hide();
        this.signUpModal?.destroy();
    }

    public validateEmail({ component }: IEventParam<TextInput>) {
        // Expressão regular para validar um e-mail
        const regex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        if (!regex.test(component.value)) {
            Utilities.alertMessage('Lembre-se de colocar um email válido @email.com', 'error');
        }
    }

    public validatePassword() {
        const senha = Metadata.getInstance<Password>('password-cadastro').value;
        const senha2 = Metadata.getInstance<Password>('password-cadastro-2').value;

        if ((senha && senha2) && (senha !== senha2)) {
            Utilities.alertMessage('As senhas não coincidem', 'error');
            return false;
        }
        return true;
    }

    public signIn() {
        const form = Metadata.getInstance<Form>('form-cadastro');

        if (this.validatePassword() && Utilities.validateForm(form)) {
            const response = Http.post('/signIn', {
                NOMECOMPLETO: Metadata.getInstance<TextInput>('nome-completo').value,
                EMAIL: Metadata.getInstance<TextInput>('email-cadastro').value,
                PASSWORD: Metadata.getInstance<Password>('password-cadastro').value,
            });
            console.warn(response);
        }
    }
}
